GO2DecBP: GO biological process (BP) descendant GO-terms as an Edgelist
Description
The GO2DecBP function provides a simple way to represent the biological process (BP) GO term.
The function returns the descendant child nodes of a GO-term. In other words we begin from an
ancestor term and find it's descendant child terms.
Usage
GO2DecBP(goterm)
Value
A vector comprising of GO-terms and the nodes they are linked to