Learn R Programming

GOxploreR (version 1.2.8)

GOTermBP2ChildLevel: Get the level of a biological process (BP) GO term's children

Description

This function retrieves a GO BP term children's level i.e. for a GO-term it's children level are derived.

Usage

GOTermBP2ChildLevel(goterm)

Value

A list of children terms and their respective levels

Arguments

goterm

A character string of a valid gene ontology id e.g "GO:0097278"

Examples

Run this code

# Retrieve "GO:0097278" children's level
GOTermBP2ChildLevel(goterm = "GO:0097278")

# Retrieve "GO:0051775" children's level
GOTermBP2ChildLevel(goterm = "GO:0051775")

Run the code above in your browser using DataLab