powered by
This function retrieves a GO CC term children's level i.e. for a GO-term it's children level are derived.
GOTermCC2ChildLevel(goterm)
A character string of a valid gene ontology id e.g "GO:0005737"
A list of children terms and their respective levels
# NOT RUN { # Retrieve "GO:0005737" children's level GOTermCC2ChildLevel("GO:0005737") # Retrieve "GO:0099568" children's level GOTermCC2ChildLevel("GO:0099568") # }
Run the code above in your browser using DataLab