# human genes
v <- c(6713,4605,55143,10615,10212,4001,2146,11130,983,4085,9833,9134)
# No value for domain is given so the default ("BP") is used
Gene2GOTermAndLevel(genes = v, organism = "Homo sapiens")
# The scientific names of the species can also be used
Gene2GOTermAndLevel(genes = v, organism = "Homo sapiens", domain = "CC")
Gene2GOTermAndLevel(genes = v, organism = "Human", domain = "MF")
Run the code above in your browser using DataLab