Learn R Programming

GOxploreR (version 1.2.8)

GetLeafNodesMF: All the MF GO-DAG leaf nodes

Description

Returns all the leaf nodes from a particular organism-specific GO-DAG. If empty (or if "MF"), all the general MF GO-DAG leaf nodes are returned. The supported organisms are "Homo sapiens / Human", "Rattus norvegicus / Rat", "Mus musculus / Mouse", "Danio rerio / Zebrafish", "Caenorhabditis elegans / Worm", "Arabidopsis thaliana / Cress", "Saccharomyces cerevisiae / Yeast", "Schizosaccharomyces pombe / Fission yeast", "Drosophila melanogaster / Fruit fly", "Escherichia coli / E.coli".

Usage

GetLeafNodesMF(organism = NULL)

Value

A two-coloum matrix of all the leaf nodes in the organism-specific DAG and their respective levels

Arguments

organism

An object of class character that represents an organism.

Examples

Run this code
# \donttest{
# Mouse MF GO-DAG leaf nodes
GetLeafNodesMF(organism = "Human")

# Arabidopsis thaliana MF GO-DAG leaf nodes
GetLeafNodesMF(organism = "Arabidopsis thaliana")

# Drosophila melanogaster MF GO-DAG leaf nodes
GetLeafNodesMF(organism = "Drosophila melanogaster")
# }

Run the code above in your browser using DataLab