Learn R Programming

GOxploreR (version 1.1.0)

Level2JumpNodeMF: Jump nodes from a GO MF level

Description

The function retrieves the Jump nodes (JNs) from a GO-level. JNs are those GO-terms which have at least one child term not present in the level below it. If the optional parameter "organism" is missing then the results are from the general GO tree. The supported organisms are "Homo sapiens / Human", "Rattus norvegicus / Rat", "Mus musculus / Mouse", "Danio rerio / Zebrafish", "Caenorhabditis elegans / Worm" ,"Arabidopsis thaliana / Cress", "Saccharomyces cerevisiae / Yeast", "Schizosaccharomyces pombe / Fission yeast", "Drosophila melanogaster / Fruit fly", "Escherichia coli / E.coli".

Usage

Level2JumpNodeMF(level, organism = NULL)

Arguments

level

A numeric value for the GO-level

organism

Organism of interest that is supported by the package

Value

All jump nodes from the level

Examples

Run this code
# NOT RUN {
# Jump nodes on level 3
Level2JumpNodeMF(level = 3, organism = "Danio rerio" )

# Jump nodes on level 6
Level2JumpNodeMF(level = 6, organism = "Caenorhabditis elegans" )
# }

Run the code above in your browser using DataLab